function CV = importCV(workbookFile, sheetName, dataLines)
%IMPORTFILE Import data from a spreadsheet
%  CV = IMPORTFILE(FILE) reads data from the first worksheet in the
%  Microsoft Excel spreadsheet file named FILE.  Returns the data as a
%  table.
%
%  CV = IMPORTFILE(FILE, SHEET) reads from the specified worksheet.
%
%  CV = IMPORTFILE(FILE, SHEET, DATALINES) reads from the specified
%  worksheet for the specified row interval(s). Specify DATALINES as a
%  positive scalar integer or a N-by-2 array of positive scalar integers
%  for dis-contiguous row intervals.
%
%  Example:
%  CV = importfile("D:\measurements\P67\12012022\CV_CMUT_0-30.xls", "Run38", [1, 302]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 14-Jan-2022 15:40:53

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 2
    dataLines = [1, 302];
end

%% Setup the Import Options and import the data
opts = spreadsheetImportOptions("NumVariables", 3);

% Specify sheet and range
opts.Sheet = sheetName;
% opts.DataRange = "A" + dataLines(1, 1) + ":C" + dataLines(1, 2);

% Specify column names and types
opts.VariableNames = ["C", "Var2", "V"];
opts.SelectedVariableNames = ["C", "V"];
opts.VariableTypes = ["double", "char", "double"];

% Specify variable properties
opts.ImportErrorRule = "omitrow";
opts.MissingRule = "omitrow";
opts = setvaropts(opts, "Var2", "WhitespaceRule", "preserve");
opts = setvaropts(opts, "Var2", "EmptyFieldRule", "auto");

% Import the data
CV = readtable(workbookFile, opts, "UseExcel", false);

for idx = 2:size(dataLines, 1)
    opts.DataRange = "A" + dataLines(idx, 1) + ":C" + dataLines(idx, 2);
    tb = readtable(workbookFile, opts, "UseExcel", false);
    CV = [CV; tb]; %#ok<AGROW>
end

end