function IV = importIV(workbookFile, sheetName, dataLines)
%IMPORTFILE Import data from a spreadsheet
%  IV = IMPORTFILE(FILE) reads data from the first worksheet in the
%  Microsoft Excel spreadsheet file named FILE.  Returns the data as a
%  table.
%
%  IV = IMPORTFILE(FILE, SHEET) reads from the specified worksheet.
%
%  IV = IMPORTFILE(FILE, SHEET, DATALINES) reads from the specified
%  worksheet for the specified row interval(s). Specify DATALINES as a
%  positive scalar integer or a N-by-2 array of positive scalar integers
%  for dis-contiguous row intervals.
%
%  Example:
%  IV = importfile("*.xls", "Run41", [1, 4002]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 14-Jan-2022 16:13:15

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 2
    dataLines = [1, 4002];
end

%% Setup the Import Options and import the data
opts = spreadsheetImportOptions("NumVariables", 3);

% Specify sheet and range
opts.Sheet = sheetName;
opts.DataRange = "B" + dataLines(1, 1) + ":D" + dataLines(1, 2);

% Specify column names and types
opts.VariableNames = ["BI", "BV", "AI"];
opts.VariableTypes = ["double", "double", "double"];

% Specify file level properties
opts.ImportErrorRule = "omitrow";
opts.MissingRule = "omitrow";

% Specify variable properties
opts = setvaropts(opts, ["BI", "BV", "AI"], "TreatAsMissing", '');
% Import the data
IV = readtable(workbookFile, opts, "UseExcel", false);

for idx = 2:size(dataLines, 1)
    opts.DataRange = "B" + dataLines(idx, 1) + ":D" + dataLines(idx, 2);    
    tb = readtable(workbookFile, opts, "UseExcel", false);
    IV = [IV; tb]; %#ok<AGROW>
    
end

end