function Vclamp = importVclamp(filename, dataLines)
%IMPORTFILE Import data from a text file
%  VCLAMP = IMPORTFILE(FILENAME) reads data from text file FILENAME for
%  the default selection.  Returns the data as a table.
%
%  VCLAMP = IMPORTFILE(FILE, DATALINES) reads data for the specified row
%  interval(s) of text file FILENAME. Specify DATALINES as a positive
%  scalar integer or a N-by-2 array of positive scalar integers for
%  dis-contiguous row intervals.
%
%  Example:
%  Vclamp = importfile("C:\Users\320033994\OneDrive - Philips\Charge retention\V clamp\test_capacitors\w184_300_300V_60s_1.csv", [2, 616]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 07-Dec-2022 11:19:57

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [2, Inf];
end

%% Setup the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 5);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = ",";

% Specify column names and types
opts.VariableNames = ["V", "I", "timestamps", "delta_time", "Qtotal"];
opts.VariableTypes = ["double", "double", "datetime", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Specify variable properties
opts = setvaropts(opts, "timestamps", "InputFormat", "yyyy-MM-dd HH:mm:ss.SSS");

% Import the data
Vclamp = readtable(filename, opts);

end