% this scritp imports the data from the CV measurements and plots them to
% analyse them 

clearvars

path = '';
wafer_number = 'w218';
load(strcat(path,wafer_number, '\data_200V'));

data = struct2table(cv{1,2}); % formats the data as a table 
% tanslate the data at the same level

for i = 1:height(data)
    data.capacitance_up{i,1} = data.capacitance_up{i,1} - ones(length(data.capacitance_up{i,1}),1).*min(data.capacitance_up{i,1});
    data.capacitance_down{i,1} = data.capacitance_down{i,1} - ones(length(data.capacitance_down{i,1}),1).*min(data.capacitance_down{i,1});
end

% import which lines had the positive unipolar and which the negative
% unipolar
[subdie_bipolar, subdie_unipolar_positive, field_positive, subdie_unipolar_negative, field_negative] = ...
    import_subdie_lines('' , wafer_number);

% subdivide the data in the correct category and assign the value of the
% chargig electric field 
data_bipolar = data(logical(sum(data.subdie == subdie_bipolar,2)),:);
data_unipolar_pos = data(logical(sum(data.subdie == subdie_unipolar_positive,2)),:);
data_unipolar_pos.field_positive = field_positive';
data_unipolar_neg = data(logical(sum(data.subdie == subdie_unipolar_negative,2)),:);
data_unipolar_neg.field_negative = field_negative';

%% plot the data

figure % bipolar
idx = 1;
plot(data_bipolar.bias_up{idx,1},data_bipolar.capacitance_up{idx,1},'k')
hold on
plot(data_bipolar.bias_down{idx,1},data_bipolar.capacitance_down{idx,1},'k')

% this plots the unipolar positive
for i = 1:height(data_unipolar_pos)
    plot(data_unipolar_pos.bias_up{i,1},data_unipolar_pos.capacitance_up{i,1},...
        'DisplayName',num2str(data_unipolar_pos.field_positive(i)))
    plot(data_unipolar_pos.bias_down{i,1},data_unipolar_pos.capacitance_down{i,1},...
        'DisplayName',num2str(data_unipolar_pos.field_positive(i)))
end
hold off
legend('Location','bestoutside') 

xlabel('Bias voltage [V]')
ylabel('Capacitance [a.u.]')
% legend('bipolar', 'bipolar', 'uni +', 'uni +', 'uni -', 'uni -', 'location', 'bestoutside')
box off;
% ylim([-0.005, 0.9])
xlim([-200, 200])


figure % bipolar
idx = 1;
plot(data_bipolar.bias_up{idx,1},data_bipolar.capacitance_up{idx,1},'k')
hold on
plot(data_bipolar.bias_down{idx,1},data_bipolar.capacitance_down{idx,1},'k')

% this plots the unipolar negative
for i = 1:height(data_unipolar_neg)
    plot(data_unipolar_neg.bias_up{i,1},data_unipolar_neg.capacitance_up{i,1},...
        'DisplayName',num2str(data_unipolar_neg.field_negative(i)))
    plot(data_unipolar_neg.bias_down{i,1},data_unipolar_neg.capacitance_down{i,1},...
        'DisplayName',num2str(data_unipolar_neg.field_negative(i)))
end
hold off
legend('Location','bestoutside') 


xlabel('Bias voltage [V]')
ylabel('Capacitance [a.u.]')
box off;
% ylim([-0.005, 0.9])
xlim([-200, 200])

%% calculate the shift in the CV curve

unbiased = array2table([mean(data_bipolar.V_col_pos), mean(data_bipolar.V_col_neg), ...
    mean(data_bipolar.V_snap_pos), mean(data_bipolar.V_snap_neg)], ...
    "VariableNames",{'V_col_pos','V_col_neg','V_snap_pos','V_snap_neg'});

% determine charging fileds in file
fields_pos = unique(data_unipolar_pos.field_positive);

charged_pos = zeros(length(fields_pos),5);
for i = 1:length(fields_pos)
    mean_col_pos = mean(table2array(data_unipolar_pos(data_unipolar_pos.field_positive == fields_pos(i),"V_col_pos")),'omitnan');
    mean_col_neg = mean(table2array(data_unipolar_pos(data_unipolar_pos.field_positive == fields_pos(i),"V_col_neg")),'omitnan');
    mean_snout_pos = mean(table2array(data_unipolar_pos(data_unipolar_pos.field_positive == fields_pos(i),"V_snap_pos")),'omitnan');
    mean_snout_neg = mean(table2array(data_unipolar_pos(data_unipolar_pos.field_positive == fields_pos(i),"V_snap_neg")),'omitnan');
    charged_pos(i,:) = [fields_pos(i), mean_col_pos, mean_col_neg, mean_snout_pos, mean_snout_neg]; 
end
charged_pos = array2table(charged_pos,"VariableNames",{'field','V_col_pos','V_col_neg','V_snap_pos','V_snap_neg'});

fields_neg = flipud(unique(data_unipolar_neg.field_negative));

charged_neg = zeros(length(fields_neg),5);
for i = 1:length(fields_neg)
    mean_col_pos = mean(table2array(data_unipolar_neg(data_unipolar_neg.field_negative == fields_neg(i),"V_col_pos")),'omitnan');
    mean_col_neg = mean(table2array(data_unipolar_neg(data_unipolar_neg.field_negative == fields_neg(i),"V_col_neg")),'omitnan');
    mean_snout_pos = mean(table2array(data_unipolar_neg(data_unipolar_neg.field_negative == fields_neg(i),"V_snap_pos")),'omitnan');
    mean_snout_neg = mean(table2array(data_unipolar_neg(data_unipolar_neg.field_negative == fields_neg(i),"V_snap_neg")),'omitnan');
    charged_neg(i,:) = [fields_neg(i), mean_col_pos, mean_col_neg, mean_snout_pos, mean_snout_neg]; 
end
charged_neg = array2table(charged_neg,"VariableNames",{'field','V_col_pos','V_col_neg','V_snap_pos','V_snap_neg'});

charged_pos.shift_V_col_pos = charged_pos.V_col_pos - unbiased.V_col_pos;
charged_pos.shift_V_col_neg = charged_pos.V_col_neg - unbiased.V_col_neg;

charged_neg.shift_V_col_pos = charged_neg.V_col_pos - unbiased.V_col_pos;
charged_neg.shift_V_col_neg = charged_neg.V_col_neg - unbiased.V_col_neg;

summary_data = [charged_pos;charged_neg];
