% Select the data to import
[files, path] = uigetfile('');

%%
imp = import_impedance(strcat(path,files));
% imp_idx = find(imp.freq <= 4.5e6);
% imp = imp(imp_idx,:);


% Extract the parameters of the impedance spectrum (for CMUTs)
% Define the model function. parameteres are in order: Rm, Cm, Lm, Ce, Rs


% First fit Cm + Ce to give a better guess for the parameter
% calculate in the first range of frequency data e.g. 200kHz
freq_log = log(imp.freq);
freq_range_low = imp.freq(imp.freq <= imp.freq(1) + 200e3);
freq_range_low_log = log(freq_range_low);

% fit the data in log log form such that they are roughly a line
CmCe_fit = fitlm(freq_range_low_log,log(imp.Z(1:length(freq_range_low_log))));
% 
% % figure;
% % plot(CmCe_fit)
% 
CmCe = predict(CmCe_fit, freq_log);
% give the guess for Ce as Cm+Ce extracted from impedance spectrum
Ce_guess = mean(1./(2 * pi * imp.freq .* exp(CmCe)));

% Ce_guess = 667e-12;
Cm_guess = 2.4e-10;  % F
% Ce_guess = Ce_guess - Cm_guess;
Rm_guess = 1e3;  % ohm
Lm_guess = 30e-6;  % H
Rs_guess = 4;  % ohm
initial_guess = [Rm_guess, Cm_guess, Lm_guess, Ce_guess, Rs_guess];
fres_guess = 1/(2*pi*sqrt(Lm_guess*Cm_guess))*1e-6


% Optimization
fun = @(params) objective_function_BVD_model(params,imp); % define the objective function

options = optimset('MaxIter', 10000, 'MaxFunEvals', 10000, 'TolFun', 1e-15, 'TolX', 1e-15);
result = fminsearch(fun, initial_guess,options);

% figure;
[mag_initial,phase_initial,~] = bode(equivalent_model(initial_guess),imp.freq*2*pi);
mag_initial = squeeze(mag_initial);
phase_initial = squeeze(phase_initial);

[mag_result,phase_result,~] = bode(equivalent_model(result),imp.freq*2*pi);
mag_result = squeeze(mag_result);
phase_result = squeeze(phase_result);

figure;
subplot(2,1,1)
loglog(imp.freq,imp.Z,'DisplayName','exp data')
hold on
% loglog(imp.freq,mag_initial)
loglog(imp.freq,mag_result,'DisplayName','fitting')
legend

subplot(2,1,2)
semilogx(imp.freq,imp.Ph)
hold on
% semilogx(imp.freq,phase_initial)
semilogx(imp.freq,phase_result)

figure;
yyaxis left
loglog(imp.freq,imp.Z,'DisplayName','exp data')
hold on
loglog(imp.freq,mag_result,'DisplayName','fitting')
legend

yyaxis right
semilogx(imp.freq,imp.Ph)
hold on
semilogx(imp.freq,phase_result)

% cplximp_exp = imp.Z .* exp(1i*deg2rad(imp.Ph));
% cplximp_result = mag_result .* exp(1i*deg2rad(phase_result));
% figure;
% yyaxis left
% semilogx(imp.freq,real(cplximp_exp),'DisplayName','exp data')
% hold on
% semilogx(imp.freq,real(cplximp_result),'DisplayName','fitting')
% ylabel('Re(Z) [ohm]')
% 
% yyaxis right
% semilogx(imp.freq,imag(cplximp_exp))
% hold on
% semilogx(imp.freq,imag(cplximp_result))
% ylabel('Img(Z) [Ohm]')
% 
% xlim([5e5 10e6])
% xlabel('Frequency [Hz]')


%% calculate the matching components values 

f = 1e6;
Rm = result(1);
Cm = result(2);
Lm = result(3);
Ce = result(4);
Rs = result(5);

[Rp_match, Lmatch, Cp_2, Ronlymatch] = calculate_matching_components(Rm, Cm, Lm, Ce, Rs, f);
results_copy = [Rm, Lm, Cm, Ce, Rs];
matching = [Rp_match; Cp_2; Lmatch; 0; Ronlymatch];
fres = 1/(2*pi*sqrt(Lm*Cm))*1e-6

[~,idx]=min(abs(imp.freq-f));
phase_at_freq_withRS = imp.Ph(idx)


% %% repeat the fitting assuming that Rs is always 11ohm
% 
% % imp_idx = find(imp.freq <= 4.5e6);
% % imp = imp(imp_idx,:);
% 
% % transform modulus and phase to real and imaginary
% [imp_real, imp_imag] = pol2cart(deg2rad(imp.Ph),imp.Z);
% 
% % subtract the series resistance
% imp_real = imp_real - 11;
% 
% % transform back to mag and phase
% [imp_phase,imp_mod] = cart2pol(imp_real,imp_imag);
% imp_phase = rad2deg(imp_phase);
% 
% 
% phase_at_freq_noRS = imp_phase(idx)


% initial_guess_noRs = [Rm, Cm, Lm, Ce, 0];
% imp_noRs = array2table([imp.freq,imp_mod,imp_phase],"VariableNames",{'freq','Z','Ph'});
% fun_noRs = @(params) objective_function_BVD_model(params,imp_noRs); % define the objective function
% result_noRs = fminsearch(fun_noRs, initial_guess_noRs,options);
% 
% % figure;
% [mag_initial_noRs,phase_initial_noRs,~] = bode(equivalent_model(initial_guess_noRs),imp.freq*2*pi);
% mag_initial_noRs = squeeze(mag_initial_noRs);
% phase_initial_noRs = squeeze(phase_initial_noRs);
% 
% [mag_result_noRs,phase_result_noRs,~] = bode(equivalent_model(result_noRs+[0 0 0 0 11]),imp.freq*2*pi);
% mag_result_noRs = squeeze(mag_result_noRs);
% phase_result_noRs = squeeze(phase_result_noRs);
% 
% figure;
% subplot(2,1,1)
% loglog(imp.freq,imp.Z,'DisplayName','exp data')
% hold on
% loglog(imp.freq,mag_result_noRs,'DisplayName','fitting')
% legend
% 
% subplot(2,1,2)
% semilogx(imp.freq,imp.Ph)
% hold on
% semilogx(imp.freq,phase_result_noRs)
% 
% Rm = result_noRs(1);
% Cm = result_noRs(2);
% Lm = result_noRs(3);
% Ce = result_noRs(4);
% Rs = result_noRs(5);


