function impedance = import_impedance_data_lifetime(filename, dataLines)
%IMPORTFILE Import data from a text file
%  IMPEDANCE = IMPORTFILE(FILENAME) reads data from text file FILENAME
%  for the default selection.  Returns the data as a table.
%
%  IMPEDANCE = IMPORTFILE(FILE, DATALINES) reads data for the specified
%  row interval(s) of text file FILENAME. Specify DATALINES as a
%  positive scalar integer or a N-by-2 array of positive scalar integers
%  for dis-contiguous row intervals.
%
%  Example:
%  impedance = importfile("C:\Users\martasaccher\OneDrive - Philips\Charge retention\Impedance spectrums\PT_batch\w223\big_CMUTs\V-264_s300_02_d20_ch20_-\L04_after_air_d20_20231204_131240.csv", [2, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 11-Dec-2023 09:10:44

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [2, Inf];
end

%% Set up the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 3);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = ",";

% Specify column names and types
opts.VariableNames = ["freq", "Z", "Ph"];
opts.VariableTypes = ["double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Import the data
impedance = readtable(filename, opts);

end