function [bipolar, unipolar_positive, field_positive, unipolar_negative, field_negative] = import_subdie_lines(workbookFile, sheetName, dataLines)
%IMPORTFILE Import data from a spreadsheet
%  [BIPOLAR, UNIPOLAR_POSITIVE, UNIPOLAR_NEGATIVE] = IMPORTFILE(FILE)
%  reads data from the first worksheet in the Microsoft Excel
%  spreadsheet file named FILE.  Returns the data as column vectors.
%
%  [BIPOLAR, UNIPOLAR_POSITIVE, UNIPOLAR_NEGATIVE] = IMPORTFILE(FILE,
%  SHEET) reads from the specified worksheet.
%
%  [BIPOLAR, UNIPOLAR_POSITIVE, UNIPOLAR_NEGATIVE] = IMPORTFILE(FILE,
%  SHEET, DATALINES) reads from the specified worksheet for the
%  specified row interval(s). Specify DATALINES as a positive scalar
%  integer or a N-by-2 array of positive scalar integers for
%  dis-contiguous row intervals.
%
%  Example:
%  [bipolar, unipolar_positive, unipolar_negative] = importfile("C:\Users\320033994\OneDrive - Philips\Charge retention\C-V_measurements\PT_batch\line_number_test_CV.xlsx", "w223", [2, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 22-Mar-2023 10:48:55

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 2
    dataLines = [2, Inf];
end

%% Set up the Import Options and import the data
opts = spreadsheetImportOptions("NumVariables", 3);

% Specify sheet and range
opts.Sheet = sheetName;
opts.DataRange = dataLines(1, :);

% Specify column names and types
opts.VariableNames = ["bipolar", "unipolar_positive", "field_positive", "unipolar_negative", "field_negative"];
opts.VariableTypes = ["double", "double", "double", "double", "double"];

% Import the data
tbl = readtable(workbookFile, opts, "UseExcel", false);

for idx = 2:size(dataLines, 1)
    opts.DataRange = dataLines(idx, :);
    tb = readtable(workbookFile, opts, "UseExcel", false);
    tbl = [tbl; tb]; %#ok<AGROW>
end

%% Convert to output type
bipolar = tbl.bipolar;
unipolar_positive = tbl.unipolar_positive;
unipolar_negative = tbl.unipolar_negative;
field_positive = tbl.field_positive;
field_negative = tbl.field_negative;

bipolar = rmmissing(bipolar)';
unipolar_positive = rmmissing(unipolar_positive)';
unipolar_negative = rmmissing(unipolar_negative)';
field_positive = rmmissing(field_positive)';
field_negative = rmmissing(field_negative)';

end